@@ -10,6 +10,7 @@ from datetime import datetime
 import pandas as pd
 from iblutil.io import parquet
 import numpy as np
+from packaging import version
 
 import one.alf.exceptions as alferr
 from one.alf.files import rel_path_parts, get_session_path, get_alf_path
@@ -45,11 +46,12 @@ def ses2records(ses: dict, int_id=False):
     eid = ses['url'][-36:]
     if int_id:
         eid = tuple(parquet.str2np(eid).flatten())
-    session_keys = ('subject', 'start_time', 'lab', 'number', 'task_protocol', 'project')
+    session_keys = ('subject', 'start_time', 'lab', 'number', 'task_protocol', 'projects')
     session_data = {k: v for k, v in ses.items() if k in session_keys}
     session = (
         pd.Series(data=session_data, name=eid).rename({'start_time': 'date'})
     )
+    session['projects'] = ','.join(session.pop('projects'))
     session['date'] = datetime.fromisoformat(session['date']).date()
 
     # Extract datasets table
@@ -554,3 +556,24 @@ def cache_int2str(table: pd.DataFrame) -> pd.DataFrame:
         table[name] = parquet.np2str(table[int_cols[i:i + 2]])
     table = table.drop(int_cols, axis=1).set_index(names)
     return table
+
+
+def patch_cache(table: pd.DataFrame, min_api_version=None) -> pd.DataFrame:
+    """Reformat older cache tables to comply with this version of ONE.
+
+    Currently this function will 1. convert integer UUIDs to string UUIDs; 2. rename the 'project'
+    column to 'projects'.
+
+    Parameters
+    ----------
+    table : pd.DataFrame
+        A cache table (from One._cache).
+    min_api_version : str
+        The minimum API version supported by this cache table.
+    """
+    min_version = version.parse(min_api_version or '0.0.0')
+    table = cache_int2str(table)
+    # Rename project column
+    if min_version < version.Version('1.13.0') and 'project' in table.columns:
+        table.rename(columns={'project': 'projects'}, inplace=True)
+    return table
